crinklywrappr.pocketsmith-api.core


account-transactionsclj

(account-transactions key
                      user
                      account
                      query-params
                      &
                      {:keys [normalize? convert? minify?] :as opts})

Returns Transactions. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy error-response?.

Returns Transactions.  Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy `error-response?`.
sourceraw docstring

accountsclj

(accounts key user & {:keys [convert? minify?]})

Returns TransactionAccounts. Expects base-currency-code to be a Joda Currency object. Throws an AssertionError if using convert? and that requirement isn't satisfied.

Returns TransactionAccounts.
Expects `base-currency-code` to be a Joda Currency object.
Throws an AssertionError if using `convert?` and that requirement isn't satisfied.
sourceraw docstring

amount->moneyclj

(amount->money amount code)

assumes code satisfies the currency? predicate

assumes `code` satisfies the `currency?` predicate
sourceraw docstring

authorized-userclj

(authorized-user key & {:keys [convert? minify?]})

Returns the authorized user. May throw an ExceptionInfo if convert? is true.

Returns the authorized user.
May throw an ExceptionInfo if `convert?` is `true`.
sourceraw docstring

bigdec?clj

(bigdec? x)
source

by-name-or-titleclj

(by-name-or-title name-or-title xs)
source

categoriesclj

(categories key user & {:keys [flatten? normalize? convert? minify?]})

Returns Categories. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy error-response?.

Returns Categories.  Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy `error-response?`.
sourceraw docstring

category-transactionsclj

(category-transactions key
                       user
                       category
                       query-params
                       &
                       {:keys [normalize? convert? minify?] :as opts})

Returns Transactions. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy error-response?.

Returns Transactions.  Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy `error-response?`.
sourceraw docstring

category-zipclj

(category-zip category)
source

category?clj

(category? x)
source

code->currencyclj

(code->currency x)
source

convert-amounts-on-accountclj

(convert-amounts-on-account user account)
source

convert-amounts-on-account*clj

(convert-amounts-on-account* user account)
source

convert-amounts-on-transactionclj

(convert-amounts-on-transaction user transaction)
source

convert-currencies-on-accountclj

(convert-currencies-on-account account)
source

convert-currencies-on-account*clj

(convert-currencies-on-account* account)
source

convert-currencies-on-transactionclj

(convert-currencies-on-transaction transaction)
source

convert-currency-code-on-userclj

(convert-currency-code-on-user user)
source

convert-datetime-on-accountclj

(convert-datetime-on-account account)
source

convert-datetime-on-account*clj

(convert-datetime-on-account* account)
source

convert-datetime-on-categoryclj

(convert-datetime-on-category category)
source

convert-datetime-on-transactionclj

(convert-datetime-on-transaction transaction)
source

convert-datetime-on-userclj

(convert-datetime-on-user user)
source

convert-identifier-for-timezoneclj

(convert-identifier-for-timezone timezone)
source

convert-timezone-on-userclj

(convert-timezone-on-user time-zones user)
source

currency?clj

(currency? x)
source

date-time?clj

(date-time? x)
source

ensure-bigdec-values-on-accountclj

(ensure-bigdec-values-on-account account)
source

ensure-bigdec-values-on-account*clj

(ensure-bigdec-values-on-account* account)
source

ensure-bigdec-values-on-transactionclj

(ensure-bigdec-values-on-transaction transaction)
source

error-response?clj

(error-response? response)

Predicate for determining if an element represents a network error or parse error

Predicate for determining if an element
represents a network error or parse error
sourceraw docstring

fetch-manyclj

(fetch-many uri key opts)
source

fetch-oneclj

(fetch-one uri key opts)
source

fetch-pageclj

(fetch-page uri key opts)
source

flatten-categoryclj

(flatten-category category)
source

get-decimal-placesclj

(get-decimal-places x)
source

get-pageclj

(get-page {:keys [status body] :as response})
source

get-transactions*clj

(get-transactions* key
                   user
                   uri
                   query-params
                   {:keys [normalize? convert? minify?]})
source

iso-8601clj

source

last-monthclj

(last-month {:keys [time-zone] :as user})

Returns a map with :start_date and :end_date keys. Intended to be passed to transaction-query-params. Will throw an assertion error if user.time-zone is not a Joda TimeZone

Returns a map with `:start_date` and `:end_date` keys.
Intended to be passed to `transaction-query-params`.
Will throw an assertion error if `user.time-zone`
is not a Joda TimeZone
sourceraw docstring

source

long->bigdecclj

(long->bigdec x)
source

minify-accountclj

(minify-account account)
source

minify-account*clj

(minify-account* account)
source

minify-categoryclj

(minify-category category)
source

minify-timezoneclj

(minify-timezone timezone)
source

minify-transactionclj

(minify-transaction transaction)
source

minify-userclj

(minify-user user)
source

modify-categoriesclj

(modify-categories f category)
source

modify-category*clj

(modify-category* f loc)
source

move-point-rightclj

(move-point-right x n)
source

next-pageclj

(next-page {:keys [status headers]})
source

normalize-categoryclj

(normalize-category category)
source

normalize-transactionclj

(normalize-transaction transaction)
source

parse-bodyclj

(parse-body {:keys [body] :as response})
source

parse-datetimeclj

(parse-datetime dt fmt)
source

(parse-link link)
source

parse-local-datetimeclj

(parse-local-datetime dt fmt)
source

request-mapclj

(request-map key)
source

time-zoneclj

(time-zone date-time)
source

time-zonesclj

(time-zones key & {:keys [convert? minify?]})

Returns pocketsmith timezone information. May throw an ExceptionInfo.

Returns pocketsmith timezone information.
May throw an ExceptionInfo.
sourceraw docstring

time-zones*clj

(time-zones* key)
source

transaction-query-paramsclj

(transaction-query-params {:keys [start-date end-date updated-since search
                                  uncategorized? type needs-review? per-page]
                           :or {per-page 100}})

formats a request map for the transaction functions.

start_date, end_date => local date objects, inclusive updated_since => datetime object, with time-zone (use to-time-zone, or from-time-zone) type => :debit or :credit uncategorized?, needs_review? => boolean search => search string per_page => number between 10 & 100

formats a request map for the transaction functions.

start_date, end_date => local date objects, inclusive
updated_since => datetime object, with time-zone (use to-time-zone, or from-time-zone)
type => :debit or :credit
uncategorized?, needs_review? => boolean
search => search string
per_page => number between 10 & 100
sourceraw docstring

user-transactionsclj

(user-transactions key
                   user
                   query-params
                   &
                   {:keys [normalize? convert? minify?] :as opts})

Returns Transactions. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy error-response?.

Returns Transactions.  Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy `error-response?`.
sourceraw docstring

cljdoc builds & hosts documentation for Clojure/Script libraries