(account-transactions key
user
account
query-params
&
{:keys [normalize? convert? minify?] :as opts})Returns Transactions. Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy error-response?.
Returns Transactions. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy `error-response?`.
(accounts key user & {:keys [convert? minify?]})Returns TransactionAccounts.
Expects base-currency-code to be a Joda Currency object.
Throws an AssertionError if using convert? and that requirement isn't satisfied.
Returns TransactionAccounts. Expects `base-currency-code` to be a Joda Currency object. Throws an AssertionError if using `convert?` and that requirement isn't satisfied.
(amount->money amount code)assumes code satisfies the currency? predicate
assumes `code` satisfies the `currency?` predicate
(authorized-user key & {:keys [convert? minify?]})Returns the authorized user.
May throw an ExceptionInfo if convert? is true.
Returns the authorized user. May throw an ExceptionInfo if `convert?` is `true`.
(categories key user & {:keys [flatten? normalize? convert? minify?]})Returns Categories. Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy error-response?.
Returns Categories. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy `error-response?`.
(category-transactions key
user
category
query-params
&
{:keys [normalize? convert? minify?] :as opts})Returns Transactions. Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy error-response?.
Returns Transactions. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy `error-response?`.
(error-response? response)Predicate for determining if an element represents a network error or parse error
Predicate for determining if an element represents a network error or parse error
(get-transactions* key
user
uri
query-params
{:keys [normalize? convert? minify?]})(last-month {:keys [time-zone] :as user})Returns a map with :start_date and :end_date keys.
Intended to be passed to transaction-query-params.
Will throw an assertion error if user.time-zone
is not a Joda TimeZone
Returns a map with `:start_date` and `:end_date` keys. Intended to be passed to `transaction-query-params`. Will throw an assertion error if `user.time-zone` is not a Joda TimeZone
(time-zones key & {:keys [convert? minify?]})Returns pocketsmith timezone information. May throw an ExceptionInfo.
Returns pocketsmith timezone information. May throw an ExceptionInfo.
(transaction-query-params {:keys [start-date end-date updated-since search
uncategorized? type needs-review? per-page]
:or {per-page 100}})formats a request map for the transaction functions.
start_date, end_date => local date objects, inclusive updated_since => datetime object, with time-zone (use to-time-zone, or from-time-zone) type => :debit or :credit uncategorized?, needs_review? => boolean search => search string per_page => number between 10 & 100
formats a request map for the transaction functions. start_date, end_date => local date objects, inclusive updated_since => datetime object, with time-zone (use to-time-zone, or from-time-zone) type => :debit or :credit uncategorized?, needs_review? => boolean search => search string per_page => number between 10 & 100
(user-transactions key
user
query-params
&
{:keys [normalize? convert? minify?] :as opts})Returns Transactions. Should not throw an exception.
If there was a network problem, or a parse error,
the last element will satisfy error-response?.
Returns Transactions. Should not throw an exception. If there was a network problem, or a parse error, the last element will satisfy `error-response?`.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |